/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/

#ifndef IDIOSKOPOSERROR_H
#define IDIOSKOPOSERROR_H

#include <typeinfo>

namespace Idioskopos {

namespace error {

  class bad_cast: public std::bad_cast {
    public:
      virtual const char * what () const throw () {
        return "idioskopos: Unable to perform property cast";
      }
  };

class read_only: public std::exception {
public:
  virtual const char* what() const throw () {
  return "idioskopos: Assignment to read only property";
  }
};

class write_only: public std::exception {
public:
  virtual const char* what() const throw () {
  return "idioskopos: Accessing a write only property";
  }
};

namespace cast {

    class wrong_property_type: public bad_cast {
    public:
      virtual const char * what () const throw () {
        return "idioskopos: Unable to cast property, casting to wrong type";
      }
  };

  class null_pointer: public bad_cast {
    public:
      virtual const char * what () const throw () {
        return "idioskopos: Cannot cast a null pointer to a property";
      }
  };

  };

class bad_property_name: public std::exception {
public:
  virtual const char * what () const throw () {
  return "idioskopos: Object does not have requested property";
  }
};

class not_a_child: public std::exception {
  public:
    virtual const char * what () const throw () {
      return "idioskopos: Requested child name doesn't exist or can't be cast to idioskopos::Object";
    }
};

};
};

#endif

